@@ -66,6 +66,7 @@ typedef struct {
 /* Function Prototypes */
 
 /* JsStr.c functions */
+int js_strnlen(char *s, u_int32_t limit);
 int js_octets(js_string *js);
 js_string *js_create(unsigned int max_count, unsigned int unit_size);
 int js_set_encode(js_string *js, int encoding);
@@ -94,6 +95,9 @@ int js_val(js_string *js, int offset);
 int js_adduint16(js_string *js, int number);
 int js_addbyte(js_string *js, unsigned char byte);
 int js_length(js_string *js);
+int js_substr_append(js_string *source, js_string *dest, int offset, int length);
+int js_readuint16(js_string *js, unsigned int offset);
+int js_tolower(js_string *js);
 
 /* JsStrOS.c functions */
 void *js_alloc(int unit_count, int unit_size);
@@ -110,6 +114,7 @@ int js_buf_read(js_file *desc);
 int js_buf_getline(js_file *desc, js_string *js);
 int js_qstr2js(js_string *js, char *string);
 int js_adduint32(js_string *js, u_int32_t number);
+u_int32_t js_readuint32(js_string *js, unsigned int offset);
 
 /* JsStrCP.c functions */
 int js_newline_chars(js_string *js);
