@@ -15,7 +15,7 @@ extern int js_space_chars();
 
 /* Keywords that are non-dictionary strings in Mara's rc file */
 
-#define KEYCOUNT 27
+#define KEYCOUNT 29
 
 char *keywords[KEYCOUNT] = {
         "bind_address", /* Address to bind to (0.0.0.0 is all addresses) */
@@ -74,6 +74,10 @@ char *keywords[KEYCOUNT] = {
         "tuzona_inetd", /* Do we run the zoneserver from inetd (security risk:
                            enabling this disables the zone_transfer_acl) */
         "verbose_level", /* How verbose error messages are */
+	"reject_aaaa", /* Send a bogus SOA whenever an AAAA request is sent
+	                  to the server */
+	"reject_ptr", /* Send a bogus SOA whenever a PTR request is sent
+	                 to the server */
         "zone_transfer_acl" /* ACL of IPs allowed to perform zone transfers */
         };
 
